import { HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectRepository } from "@nestjs/typeorm";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";
import { ProductDetailsPageUiRepository } from "./product-details-page-ui.repository";
import { UpdateProductDetailsPageUiDto } from "./dto/update-product-details-page-ui.dto";
import { ProductDetailsPageUI } from "./entities/product-details-page-ui.entity";

@Injectable()
export class ProductDetailsPageUiService {
    constructor(
      @InjectRepository(ProductDetailsPageUiRepository)
      private readonly repository: ProductDetailsPageUiRepository,
      private readonly doSpaceService: DoSpacesService
    ) {
    }

    async updateOrCreateData(
      dto: UpdateProductDetailsPageUiDto
    ): Promise<ProductDetailsPageUI | Error> {
        const isExists = await this.repository.find({ isDeleted: false });
        if (Object.keys(isExists).length === 0) {
            const data = await this.repository.createEntity(dto);
            if (!data) {
                throw new HttpException(
                  Constants.NOT_FOUND,
                  HttpStatus.NOT_FOUND
                );
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            let id = isExists[0].id;
            const data = await this.repository.updateEntity(dto, id);
            if (!data) {
                throw new HttpException(
                  Constants.UPDATE_FAILED,
                  HttpStatus.BAD_REQUEST
                );
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<ProductDetailsPageUI[] | Error> {
        const data = await this.repository.findAll();
        if (!data) {
            throw new HttpException(
              Constants.NOT_FOUND,
              HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}