import { EntityRepository, getConnection, Repository } from "typeorm";
import { CreateProductReviewDto } from "./dto/create-product-review.dto";
import { ProductReview } from "./entities/product-review.entity";

@EntityRepository(ProductReview)
export class ProductReviewRepository extends Repository<ProductReview> {
    async createEntity(dto: CreateProductReviewDto): Promise<ProductReview | Error> {
        try {
            const {
                productId,
                productName,
                rating,
                name,
                likeOrDislikeMsg,
                reviewSummary
            } = dto;
            const entity = this.create({
                productId,
                productName,
                rating,
                name,
                likeOrDislikeMsg,
                reviewSummary
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<ProductReview | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<ProductReview[] | Error> {
        try {
            return await this.find({
                where: {
                    ...query,
                    isDeleted: false
                },
                order: {
                    createdAt: "DESC"
                }
            });
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
              .createQueryBuilder()
              .update(ProductReview)
              .set({ isDeleted: true })
              .where("id = :id", { id: id })
              .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }
}